# Acute Protocol Exerciser Python Libraries (AQPXLIB)

[![License](https://img.shields.io/badge/License-BSD_3--Clause-orange.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![PyPI](https://img.shields.io/pypi/v/aqpxlib)](https://pypi.org/project/aqpxlib/)

The **Protocol Exerciser Library** is a friendly interface to interact with Acute's Protocol Exerciser instruments. 

The key features are:

  * **Friendly**: The library is fully written in Python with comprehensive type hints.
  * **Intuitive**: Actions initiated by these simulated devices are just like real ones.
  * **Easy to use**: Designed to be easy to use and integrate into your own projects.

## Supported series

| Type | Product Series |
| ---- | -------------- |
| Protocol Exerciser | [PX2816B](https://www.acute.com.tw/) |
